/*  ---------------------------------------------------------------------------
    Program  :  getAxisMax.sas

    Path     :  C:\N08\CustomAxis\Mac\MKUNDERLYINGSCALE.SAS (the calling
                macro)

    Purpose  :  Obtain maximum range value for an axis where the BY value
                 can be either integer or real.

    Parms    :  Name           Description                   Default
                ---------  -------------------------------   --------
                Max        Maximum value derived from data   none
                By         By value entered by user          none

    Examples :  %let XMax=%getAxisMax(Max=0.9321, by=0.02); XMax = 0.94
                %let XMax=%getAxisMax(Max=-13, by=2);       XMax = -12
     ------------------------------------------------------------------------  */
 %macro getAxisMax(Max=, by=);
  %Local adjMax intBy intMax modX multiplier notFound ;
  %let notFound = 1;
  %let multiplier = 1;
  %do %while (&notFound);  
    %let intMax=%sysevalf(&multiplier * &Max);
    %let intBy=%sysevalf(&multiplier * &by);
    %if %sysfunc(floor(&intBy)) ne %sysfunc(ceil(&intBy)) %then %do;
       %let multiplier = %sysevalf(&multiplier * 10.0);
    %end;
    %else %do;
       %let notFound = 0;
    %end;
  %end;
  %let intMax=%sysfunc(ceil(&intMax));
  %let modX = %sysfunc(mod(&intMax,&intBy));
  %do %while (%eval(&modX) ne 0);
    %let intMax=%eval(&intMax +1);
    %let modX = %sysfunc(mod(&intMax,&intBy));
  %end;
  %let adjMax=%sysevalf(&intMax/&multiplier);
  &adjMax
 %mend getAxisMax;
