/*  ---------------------------------------------------------------------------
    Program  :  getAxisMin.sas

    Path     :  C:\N08\CustomAxis\Mac\MKUNDERLYINGSCALE.SAS (the calling
                macro)

    Purpose  :  Obtain minimum range value for an axis where the BY value
                 can be either integer or real.

    Parms    :  Name           Description                   Default
               ---------  --------------------------------   --------
               Min         minimum value derived from data    none
               By          By value entered by user           none

    examples : %let XMin=%getAxisMin(Min=0.9321, by=0.02); Xmin = 0.92
               %let Xmin=%getAxisMin(Min=-13, by=2);       Xmin = -14
     ------------------------------------------------------------------------  */
 %macro getAxisMin(Min=, by=);
  %Local adjMin intBy intMin modX multiplier notFound ;
  %let notFound = 1;
  %let multiplier = 1;
  %do %while (&notFound);  
    %let intMin=%sysevalf(&multiplier * &Min);
    %let intBy=%sysevalf(&multiplier * &by);
    %if %sysfunc(floor(&intBy)) ne %sysfunc(ceil(&intBy)) %then %do;
       %let multiplier = %sysevalf(&multiplier * 10.0);
    %end;
    %else %do;
       %let notFound = 0;
    %end;
  %end;
  %let intMin=%sysfunc(floor(&intMin));
  %let modX = %sysfunc(mod(&intMin,&intBy));
  %do %while (%eval(&modX) ne 0);
    %let intMin=%eval(&intMin -1);
    %let modX = %sysfunc(mod(&intMin,&intBy));
  %end;
  %let adjMin=%sysevalf(&intMin/&multiplier);
  &adjmin
 %mend getAxisMin;
 
