/*  ---------------------------------------------------------------------------
    Program  :  UnevenIntervalAxis.sas

    Path     :  C:\SASPapers\CustomAxis\Mac

    Purpose  :  Create an uneven X axis where ticks coincide with a finite
                number of X-coordinates in the data. Ticks are labeled with
                values for the X-coordinates.

    Parms    :  Name                   Description                         Required
                ---------          --------------------------------        --------
                INDS               Input data set name                     yes
                XVAR               Horizontal axis variable name           yes
                PCTSIZE            Text Size in PCT                        yes
                                    Output from %Pt2Size in the
                                    in the calling program.
                XLABEL             X-axis label                            yes
                YORIGIN            Vertical origin in percent              yes
                XVALFMT            Format used to display tick             no
                                    marks along the X-Axis.            
    Input    :  &inDS
    Output   :  work.annoAxisX
    ------------------------------------------------------------------------  */

  %macro UnevenIntervalAxis(inDS=, xvar=, pctSize=, xlabel=, yOrigin=, XvalFmt=);
     %annomac;
     %local tickLength labelYpos axisLabelPos;
     %let tickLength=1;
     %let labelYpos=3.5;
     %let axisLabelPos=9; 

     proc sql noprint;
       create table distinctXtick as
       select distinct &xvar as xtick from &inDS
       order by &xvar;
     quit;
     data distinctXtick;
       length DisplayX $15;
       set distinctXtick;
       %if &Xvalfmt eq %then %do;
         fmtYvN=0;
         DisplayX=left(put(xtick,best.));
       %end;
       %else %do;
         fmtYvN=1;
         displayX=left(trim(put(xtick, &xValFmt.)));
       %end;
     run;

     data annoAxisX;
       %dclanno;
       length text $30; /* %dclanno takes care of the rest */
       set distinctXtick end=last;
         %system(2,3,3);
         %move(xtick, &yOrigin);
         %draw(xtick, &yOrigin - &tickLength., black, 1, 0.04);
         %label(xtick, &yOrigin - &LabelYpos., DisplayX, black, 0, 0, &pctSize, Hwcgm001,5);
         if last then do;
          %system(1,3,3);
          %label(50, &yOrigin - &axisLabelPos., "&xLabel", black, 0, 0, &pctSize, Hwcgm002,5);
         end;
     run;
 %mend UnevenIntervalAxis;
