/*  ---------------------------------------------------------------------------
    Program  :  mkUnderlyingScale.sas

    Path     :  C:\N08\CustomAxis\Mac

    Purpose  :  Macro function that creates an order statement in a hidden 
                axis where the distance between major tick marks is very small.
                
    Output   :  An explicit range in &XMIN to &XMAX by &Xby format.

    Parms    :  NAME            DESCRIPTION                             DEFAULT
                ---------       --------------------------------        --------
                CALCXMIN        XMIN calculated from input data         none (required)
                                  in the calling program
                CALCXMAX        XMAX calculated from input data         none (required)
                                  in the calling program
                MINOFFSET       IF GT 0 then adjust CALCXMIN by         blank
                                -&MINOFFSET * &XBY.  
                MAXOFFSET       IF GT 0 then adjust CALCXMAX by         blank
                                &MAXOFFSET * &XBY.  

    Note     :                  For Histograms, OFFSET is balanced.
                                In this version of mkUnderlyingScale
                                X-axis offsets can be different.
    Macros
    Called   :  GETINCR         Calculates the narrow increment used in the
                                order statement and used to stretch the
                                axis when desired.
                GETAXISMIN      Re-calculates Axis minimum with output from
                                GETINCR.
                GETAXISMAX      Re-calculates Axis maximum with output from
                                GETINCR.
    ------------------------------------------------------------------------  */
%put FULLPATH: %sysget(SAS_EXECFILEPATH);
 %macro MkUnderlyingScale(calcXMin=, calcXMax=, minOffset=, maxOffset=);
    %local rangeX xBy xmin xmax;
    %let rangeX = %sysevalf(&calcXMax - &calcXmin);
    %let xBy= %getIncr(range=&rangeX);
    %let calcXmin = %sysevalf(&calcXmin - &xBy);
    %let calcXmax = %sysevalf(&calcXmax + &xBy);
    %if &minOffset gt 0 %then
      %let calcXmin=%sysevalf(&calcXmin - (&minOffset * &Xby) );
    %if &maxOffset gt 0 %then
      %let calcXmax=%sysevalf(&calcXmax + (&maxOffset * &Xby) );
  /* FINAL ENDPOINTS WHERE XMIN AND XMAX ARE FACTORS OF XBY 
     SUPPLIED BY MACRO FUNCTION*/    
     %let xMin=%getAxisMin(min=&calcXmin, by=&Xby);
     %let xMax=%getAxisMax(max=&calcXmax, by=&Xby);
     &XMIN to &XMAX by &Xby
%mend MkUnderlyingScale;
